@@ -42,7 +42,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.6'; # VERSION
+our $VERSION = 'v0.8.7'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -353,8 +353,9 @@ sub configure {
             } ],
         } ],
 
-        [ 'Hook::Init' => 'my vars' => {
+        [ 'Hook::Init' => 'init stuff' => {
             'hook' => [ q[
+                $dist->license->{ program } = 'perl-' . $dist->name;
                 { pack] . q[age MY;     # Hide declaration from `new-version.t`.
                     our $name           = $dist->name;
                     ( our $package      = $name ) =~ s{-}{::}g;
@@ -957,7 +958,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.6, released on 2015-10-03 10:53 UTC.
+Version v0.8.7, released on 2015-10-03 13:38 UTC.
 
 =head1 WHAT?
 
@@ -1067,40 +1068,35 @@ perl-Dist-Zilla-PluginBundle-Author-VDB. If not, see <http://www.gnu.org/license
 
 __DATA__
 
+__[ not a real section, just a comment ]__
+
+#   `perldoc` interprets POD even after `__DATA__`, so module documentation will include all the
+#   sections below. To avoid this undesired behavour, prepend each POD directive with backslash â
+#   it will be stripped by `Data::Section`.
+
 __[ doc/copying.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 COPYRIGHT AND LICENSE
+\=head1 COPYRIGHT AND LICENSE
 
-Copyright Â© 2015 Van de Bugger
-
-C<perl-{{$MY::name}}> is free software: you can redistribute it and/or modify it under the
-terms of the GNU General Public License as published by the Free Software Foundation, either
-version 3 of the License, or (at your option) any later version.
-
-C<perl-{{$MY::name}}> is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-C<perl-{{$MY::name}}>. If not, see L<http://www.gnu.org/licenses/>.
+{{$dist->license->notice();}}
 
 C<perl-{{$MY::name}}> I<distribution> may contain files generated by C<Dist-Zilla> and/or its
 plugins from third-party templates; copyright and license specified above are I<not> applicable to
 that files.
 
-=cut
+\=cut
 
 __[ doc/distribution.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 DISTRIBUTION
+\=head1 DISTRIBUTION
 
 C<{{$MY::name}}> distributions are published on L<CPAN|{{$MY::metacpan}}>.
 
-=head2 Generated Files
+\=head2 Generated Files
 
 Distribution may contain files preprocessed or generated by C<Dist-Zilla> and its plugins. Some
 generated files are made from C<{{$MY::name}}> source, but some are generated from
@@ -1113,19 +1109,19 @@ the top of the file:
 C<{{$MY::name}}> source, and C<{{$MY::name}}> copyright and license are not applicable
 to such files.
 
-=cut
+\=cut
 
 __[ doc/documentation.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 DOCUMENTATION
+\=head1 DOCUMENTATION
 
-=head2 Online
+\=head2 Online
 
 The easiest way is browsing the documentation L<online at meta::cpan|{{$MY::metacpan}}>.
 
-=head2 Locally Installed
+\=head2 Locally Installed
 
 If you have the distribution installed, use C<perldoc> tool to browse locally
 installed documentation:
@@ -1133,7 +1129,7 @@ installed documentation:
     $ perldoc {{$MY::package}}::Manual
     $ perldoc {{$MY::package}}
 
-=head2 Built from Source
+\=head2 Built from Source
 
 Build C<{{$MY::name}}> first (see L</"HACKING">), then:
 
@@ -1143,28 +1139,28 @@ Build C<{{$MY::name}}> first (see L</"HACKING">), then:
 
 where I<VERSION> is a version of built distribution.
 
-=cut
+\=cut
 
 __[ doc/feedback.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 FEEDBACK
+\=head1 FEEDBACK
 
-=head2 CPAN Request Tracker
+\=head2 CPAN Request Tracker
 
 The quickest way to report a bug in C<{{$MY::name}}> is by sending email to
 bug-{{$MY::name}} [at] rt.cpan.org.
 
 CPAN request tracker can be used via web interface also:
 
-=over
+\=over
 
-=item L<Browse bugs|{{$MY::cpan_rt_browse}}>
+\=item L<Browse bugs|{{$MY::cpan_rt_browse}}>
 
 Browsing bugs does not require authentication.
 
-=item L<Report bugs|{{$MY::cpan_rt_report}}>
+\=item L<Report bugs|{{$MY::cpan_rt_report}}>
 
 You need to be a CPAN author, have a L<BitCard|https://www.bitcard.org/> account, or OpenID in
 order to report bugs via the web interface.
@@ -1172,20 +1168,20 @@ order to report bugs via the web interface.
 (On 2015-04-27 I have logged in successfully with my LiveJournal OpenID, but my Google OpenID did
 not work for CPAN. I did not check other OpenID providers.)
 
-=back
+\=back
 
-=head2 Send Email to Author
+\=head2 Send Email to Author
 
 As a last resort, send email to author: {{$MY::author}}. Please start message subject with
 "perl-{{$MY::name}}:".
 
-=cut
+\=cut
 
 __[ doc/forms.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 FORMS
+\=head1 FORMS
 
 You may face C<{{$MY::name}}> in I<source> or I<distribution> forms.
 
@@ -1199,69 +1195,69 @@ they are Perl source files. But they are not I<actual> sources, because they are
 
 How to distinguish source and distribution:
 
-=over
+\=over
 
-=item *
+\=item *
 
 Source may contain Mercurial files and directories F<.hgignore>, F<.hgtags>, F<.hg/>, while
 distribution should not.
 
-=item *
+\=item *
 
 Source should contain files F<dist.ini>, F<weaver.ini>, while distribution may not.
 
-=item *
+\=item *
 
 Source should I<not> contain F<xt/> directory, while distribution should.
 
-=item *
+\=item *
 
 Name of source directory does I<not> include version (e. g. C<{{$MY::name}}>), while name of
 distribution does (e. g. C<{{$MY::name}}-0.007>).
 
-=back
+\=back
 
-=cut
+\=cut
 
 __[ doc/glossary.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 GLOSSARY
+\=head1 GLOSSARY
 
-=over
+\=over
 
-=item CPAN
+\=item CPAN
 
 Comprehensive Perl Archive Network, a B<large> collection of Perl software and documentation. See
 L<cpan.org|http://www.cpan.org>, L<What is
 CPAN?|http://www.cpan.org/misc/cpan-faq.html#What_is_CPAN>.
 
-=item Distribution
+\=item Distribution
 
 Tarball, containing Perl modules and accompanying files (documentation, metainfo, tests). Usually
 distributions are uploaded to CPAN, and can be installed with dedicated tools (C<cpan>, C<cpanm>,
 and others).
 
-=item Module
+\=item Module
 
 Perl library file, usually with C<.pm> suffix. Usually contains one package. See
 L<perlmod|http://perldoc.perl.org/perlmod.html#Perl-Modules>.
 
-=item Package
+\=item Package
 
 Perl language construct. See L<package|http://perldoc.perl.org/functions/package.html> and
 L<perlmod|http://perldoc.perl.org/perlmod.html#Packages>.
 
-=back
+\=back
 
-=cut
+\=cut
 
 __[ doc/hacking.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 HACKING
+\=head1 HACKING
 
 For hacking, you will need Mercurial, Perl interpreter and C<Dist-Zilla> (with some plugins), and
 likely C<cpanm> to install missed parts.
@@ -1307,15 +1303,15 @@ To clean the directory:
 
     $ dzil clean
 
-=cut
+\=cut
 
 __[ doc/installing.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 INSTALLING
+\=head1 INSTALLING
 
-=head2 With C<cpanm>
+\=head2 With C<cpanm>
 
 C<cpanm> tool is (probably) the easiest way to install distribution. It automates downloading,
 building, testing, installing, and uninstalling.
@@ -1337,7 +1333,7 @@ To uninstall the distribution:
 
     $ cpanm -U {{$MY::package}}
 
-=head2 Manually
+\=head2 Manually
 
 To install distribution tarball manually (let us assume you have version I<0.007> of the
 distribution):
@@ -1349,17 +1345,17 @@ distribution):
     $ ./Build test
     $ ./Build install
 
-=head2 See Also
+\=head2 See Also
 
 L<How to install CPAN modules|http://www.cpan.org/modules/INSTALL.html>
 
-=cut
+\=cut
 
 __[ doc/naming.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 NAMING
+\=head1 NAMING
 
 C<perl-{{$MY::name}}> is official software name.
 
@@ -1373,13 +1369,13 @@ You may notice that name may be spelled with dashes (C<{{$MY::name}}>) or with d
 name, while the second is name of Perl package, but often these names are interchangeable
 especially if software consists of single package.
 
-=cut
+\=cut
 
 __[ doc/source.pod ]__
 
-=encoding UTF-8
+\=encoding UTF-8
 
-=head1 SOURCE
+\=head1 SOURCE
 
 C<{{$MY::name}}> source is in Mercurial repository hosted on {{$MY::repo_host}}.
 {{$MY::repo_web ? "You can either L<browse the source online|{{$MY::repo_web}}> or " : "To
@@ -1387,7 +1383,7 @@ C<{{$MY::name}}> source is in Mercurial repository hosted on {{$MY::repo_host}}.
 
     $ {{$MY::repo_clone}}
 
-=head2 Source Files
+\=head2 Source Files
 
 C<{{$MY::name}}> source files usually include a comment near the top of the file:
 
@@ -1396,7 +1392,7 @@ C<{{$MY::name}}> source files usually include a comment near the top of the file
 Not all source files are included into distribution. Some source files are used at distribution
 build time only, and not required for installation.
 
-=cut
+\=cut
 
 __END__
 
